@@ -1,6 +1,7 @@
-import gpiod
+# pylint: disable=missing-docstring
 import sys
 from datetime import timedelta
+from .. import chip, line_request, line_event
 
 try:
     if len(sys.argv) > 2:
@@ -9,27 +10,28 @@ try:
         if len(sys.argv) > 3:
             edge = sys.argv[3]
             if edge[0] == "r":
-                BUTTON_EDGE = gpiod.line_request.EVENT_RISING_EDGE
+                BUTTON_EDGE = line_request.EVENT_RISING_EDGE
             elif edge[0] == "f":
-                BUTTON_EDGE = gpiod.line_request.EVENT_FALLING_EDGE
+                BUTTON_EDGE = line_request.EVENT_FALLING_EDGE
             else:
-                BUTTON_EDGE = gpiod.line_request.EVENT_BOTH_EDGES
+                BUTTON_EDGE = line_request.EVENT_BOTH_EDGES
         else:
-            BUTTON_EDGE = gpiod.line_request.EVENT_BOTH_EDGES
+            BUTTON_EDGE = line_request.EVENT_BOTH_EDGES
 
     else:
         raise Exception()
-except:
+# pylint: disable=broad-except
+except Exception:
     print(
         """Usage:
-    python3 -m gpiod.test.button <chip> <line offset> [rising|falling|both]"""
+    python3 -m test.button <chip> <line offset> [rising|falling|both]"""
     )
     sys.exit()
 
-chip = gpiod.chip(BUTTON_CHIP)
-button = chip.get_line(BUTTON_LINE_OFFSET)
+c = chip(BUTTON_CHIP)
+button = c.get_line(BUTTON_LINE_OFFSET)
 
-config = gpiod.line_request()
+config = line_request()
 config.consumer = "Button"
 config.request_type = BUTTON_EDGE
 
@@ -41,7 +43,7 @@ while True:
     if button.event_wait(timedelta(seconds=10)):
         # event_read() is blocking function.
         event = button.event_read()
-        if event.event_type == gpiod.line_event.RISING_EDGE:
+        if event.event_type == line_event.RISING_EDGE:
             print("rising: ", event.timestamp)
         else:
             print("falling: ", event.timestamp)
